Slack connector using official Java SDK. Sends hivemind events to Slack channels.
Slack connector using official Java SDK. Sends hivemind events to Slack channels.
(create-client)Create a reusable Slack client instance. The client is thread-safe and should be reused across calls.
Create a reusable Slack client instance. The client is thread-safe and should be reused across calls.
(format-hivemind-event {:keys [a e m]})Format a hivemind event for Slack display.
Event map keys: :a - agent ID (e.g., "ling-1") :e - event type (started, progress, completed, error, blocked) :m - message content
Returns formatted mrkdwn string.
Format a hivemind event for Slack display. Event map keys: :a - agent ID (e.g., "ling-1") :e - event type (started, progress, completed, error, blocked) :m - message content Returns formatted mrkdwn string.
(notify-channel! token channel event)Send a formatted hivemind event to a Slack channel.
Args: token - Slack bot token channel - Target channel event - Hivemind event map {:a agent-id :e event-type :m message}
Returns: Result map from send-message!
Send a formatted hivemind event to a Slack channel.
Args:
token - Slack bot token
channel - Target channel
event - Hivemind event map {:a agent-id :e event-type :m message}
Returns:
Result map from send-message!(send-message! token channel text)Send a message to a Slack channel.
Args: token - Slack bot token (xoxb-...) channel - Channel name (#general) or ID (C01234...) text - Message text (supports Slack mrkdwn formatting)
Returns: {:ok true} on success {:ok false :error "error_code"} on failure
Send a message to a Slack channel.
Args:
token - Slack bot token (xoxb-...)
channel - Channel name (#general) or ID (C01234...)
text - Message text (supports Slack mrkdwn formatting)
Returns:
{:ok true} on success
{:ok false :error "error_code"} on failurecljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |